## No image output examples

This section gathers examples which don't produce any figures. Some examples
only output to standard output, others demonstrate how Mkdocs-Gallery handles
examples with errors.
